from setuptools import setup

NAME = 'xzc'
VERSION = '1.0'
PACKAGES = ['xzc']
setup(name=NAME
      , version=VERSION
      , packages=PACKAGES,
      description='a small pkg demos for everyone of students',
      long_description='''

pip install xzc

'''
      , long_description_content_type='text/markdown'
      )
